Flaminkit
=========

A toolkit for the FLAMINGO cosmological hydrodynamical simulation suite

.. note::

    Currently only works with HBT+ catalogs.

Installation
------------

Flaminkit can be installed through ``pip``: ::

    pip install flaminkit


See the `documentation <https://flaminkit.readthedocs.io/en/latest/>`_ for more details.